@@ -6,12 +6,12 @@ Transcode media file to another format/codecs
 ---------------------------------------------
 :py:func:`ffmpegio.transcode()`
 
-Simple Read/Write Streams
--------------------------
+Stream Read/Write
+-----------------
 ffmpegio.open()
 
-Simple Read/Write Functions
----------------------------
+Block Read/Write Functions
+--------------------------
 `ffmpegio.video.read()`
 `ffmpegio.video.write()`
 `ffmpegio.image.read()`
@@ -30,7 +30,7 @@ from . import ffmpeg as _ffmpeg
 from . import streams as _streams
 
 __all__ = ["transcode", "caps", "probe", "set_path", "audio", "image", "video", "open"]
-__version__ = "0.0.8"
+__version__ = "0.0.9"
 
 ffmpeg_info = _ffmpeg.versions
 set_path = _ffmpeg.find
