@@ -264,13 +264,17 @@ def input_timing(
 
         inopts = file_entry[1]
         if start:
-            inopts["ss"] = float(start / fs)
+            inopts["ss"] = start if isinstance(start, str) else float(start / fs)
         elif end and duration:
+            if isinstance(end, str) or isinstance(duration, str):
+                raise Exception(
+                    "when specifying end and duration, they both must be numeric"
+                )
             inopts["ss"] = float((end - duration) / fs)
         if end:
-            inopts["to"] = float(end / fs)
+            inopts["to"] = end if isinstance(start, str) else float(end / fs)
         if duration:
-            inopts["t"] = float(duration / fs)
+            inopts["t"] = duration if isinstance(start, str) else float(duration / fs)
 
     return ffmpeg_args
 
@@ -575,10 +579,8 @@ def video_io(
     :type transpose: int
     :param rotate: degrees to rotate video frame clockwise
     :type rotate: float
-    :param deinterlace: apply selected deinterlacing filter if available
-    :type {'bwdif','estdif','kerndeint','nnedi','w3fdif','yadif','yadif_cuda'}
 
-    Filter Order: crop=>flip=>transpose=>deinterlace=>rotate=>scale
+    Filter Order: crop=>flip=>transpose=>rotate=>scale
 
 
     """
@@ -633,10 +635,9 @@ def video_io(
     if fg_outputs is None:
         fg_outputs = fg_labels["output_labels"] = {}
 
-    for i in range(nstreams):
+    for i, opts in enumerate(ffmpeg_opts):
 
         st_id = stream_ids[i]
-        opts = ffmpeg_opts[i]
         filt_def = opts.pop("vf", None)
 
         in_spec = out_spec = utils.spec_stream(st_id, "v", file_index=in_file_id)
@@ -686,7 +687,7 @@ def video_io(
 
     out_cfg["map"] = out_map
     if len(fg) > 0:
-        merge_user_options(ffmpeg_args, "global", {"filter_complex": (*fg, fg_labels)})
+        merge_user_options(ffmpeg_args, "global", {"filter_complex": (fg, fg_labels)})
 
     return ffmpeg_args, reader_cfgs
 
@@ -845,32 +846,25 @@ def video_stream(
             vfilters.append("vflip")
 
     transpose = stream_opts.get("transpose", None)
-    if transpose:
-        vfilters.append(("transpose", transpose % 4))
+    if transpose is not None:
+        vfilters.append(("transpose", transpose))
+        if h > w or (isinstance(transpose, int) and transpose < 4):
+            w, h = h, w
+            # 4-7, the transposition is only done if the input video geometry is portrait and not landscape
 
-    deint = stream_opts.get("deinterlace", None)
-    if deint:
-        # fmt: off
-        if deint not in ("bwdif", "estdif", "kerndeint", "nnedi", "w3fdif", "yadif", "yadif_cuda"):
-            raise Exception("Invalid deinterlacing filter specified.")
-        # fmt: on
-        vfilters.append(deint)
-        h *= 2
-
-    rot = stream_opts.get("rotate", None)
-    if rot:
-        w, h = utils.get_rotated_shape(w, h, rot)
+    rotdeg = stream_opts.get("rotate", None)
+    if rotdeg:
+        w, h, rot = utils.get_rotated_shape(w, h, rotdeg)
         vfilters.append(("rotate", rot, w, h, {"c": bg_color}))
 
     size = stream_opts.get("size", None)
     scale = stream_opts.get("scale", None)
     if size or scale:
         if size:
-            if size[0] <= 0:
-                size[0] = size[1] * w / h
-            elif size[1] <= 0:
-                size[1] = size[0] * h / w
-            w, h = size
+            w, h = (
+                size[1] * w / h if size[0] <= 0 else size[0],
+                size[0] * h / w if size[1] <= 0 else size[1],
+            )
         else:
             sep = isinstance(scale, Sequence)
             w *= scale[0] if sep else scale
@@ -1018,18 +1012,34 @@ def filters(
     return ffmpeg_args
 
 
-def get_audio_range(ffmpeg_args, stream_id=0):
-    url, opts = ffmpeg_args["inputs"][stream_id]
-    info = probe.audio_streams_basic(url, stream_id, ("sample_rate", "nb_samples"))[0]
+def get_audio_range(ffmpeg_args, file_id=0, stream_id=0):
+    """estimated range of audio sample indices
+
+    :param ffmpeg_args: argument dict to ffmpeg
+    :type ffmpeg_args: dict
+    :param file_id: audio input file index, defaults to 0
+    :type file_id: int, optional
+    :param stream_id: audio stream index, defaults to 0
+    :type stream_id: int, optional
+    :return: tuple of first and (exclusive) last sample indices
+    :rtype: tuple(int, int)
+    """
+    url, opts = ffmpeg_args["inputs"][file_id]
+    info = probe.audio_streams_basic(url, file_id, ("sample_rate", "nb_samples"))[0]
     fs = info["sample_rate"]
     i0 = 0
     i1 = info["nb_samples"]
     if opts is not None:
-        ss = get_option(ffmpeg_args, "input", "ss")
-        t = get_option(ffmpeg_args, "input", "t")
-        to = get_option(ffmpeg_args, "input", "to")
+        ss = utils.parse_time_duration(get_option(ffmpeg_args, "input", "ss"))
+        t = utils.parse_time_duration(get_option(ffmpeg_args, "input", "t"))
+        to = utils.parse_time_duration(get_option(ffmpeg_args, "input", "to"))
         ar = get_option(
-            ffmpeg_args, "input", "ar", stream_type="a", stream_id=stream_id
+            ffmpeg_args,
+            "input",
+            "ar",
+            file_id=file_id,
+            stream_type="a",
+            stream_id=stream_id,
         )
         if ar is not None:
             fs = ar
